summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMark Benvenuto <mark.benvenuto@mongodb.com>2022-08-08 13:23:36 -0400
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2022-08-22 21:20:29 +0000
commitfea0030c24c8d5658f2249bb15c8546350929e59 (patch)
tree296f030587d6a17bb8bdd82b00e10877014ce76b
parent017318d3281c4b6f04dfdfd74ad382c6354191cb (diff)
downloadmongo-fea0030c24c8d5658f2249bb15c8546350929e59.tar.gz
SERVER-68399 Fix parsing of safeint version numbers in blackduck_hub.py
(cherry picked from commit 4b9b3427725b54b01e8fa4d7ed207b61551ad5fe)
-rw-r--r--buildscripts/blackduck_hub.py7
1 files changed, 4 insertions, 3 deletions
diff --git a/buildscripts/blackduck_hub.py b/buildscripts/blackduck_hub.py
index acaca6c3946..15746f3773d 100644
--- a/buildscripts/blackduck_hub.py
+++ b/buildscripts/blackduck_hub.py
@@ -86,7 +86,7 @@ THIRD_PARTY_COMPONENTS_FILE = "etc/third_party_components.yml"
############################################################################
-RE_LETTERS = re.compile("[A-Za-z]{2,}")
+RE_LETTER = re.compile("[A-Za-z]")
def default_if_none(value, default):
@@ -331,8 +331,9 @@ class VersionInfo:
if self.ver_str.endswith('-'):
self.ver_str = self.ver_str[0:-1]
- # Boost keeps varying the version strings so filter for anything with 2 or more ascii charaters
- if RE_LETTERS.search(self.ver_str):
+ # Boost keeps varying the version strings so filter for anything with a letter
+ # Safeint has "3.0.26c" as a version number
+ if RE_LETTER.search(self.ver_str):
self.production_version = False
return